/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/drvmio.h"              */
/*  Constants and definitions for I/O container drivers.                     */
/*                                                                           */
/*  Author : JYA                        Last modification : 02/11/2016       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
         2  Structures and typedefs
            2.1  Structures de description drivers systemes (ROM)
            2.2  Structures de description drivers/protocoles/services (ROM)
            2.3  Structure de description d'un board (ROM)
            2.4  Structure de description du driver systeme ecran (ROM)
         3  Public variable
         4  Prototypes of public procedures


*/


#ifndef DRVMIO_H                       /* If this file is not already        */
#define DRVMIO_H                       /* included, include it.              */

/*
    1    Defines
    ____________
*/

/* Used banks: main define ..................................................*
 * The define below is based on the "Table 8. STM32L151xE and STM32L152xE    *
 * pin definitions" p37-45.                                                  */

#define BANKS_A_TO_C

/* Used banks ...............................................................*
 * The defines below are based on the "Table 8. STM32L151xE and STM32L152xE  *
 * pin definitions" p37-45.                                                  */

#ifdef BANKS_A_TO_H                    /* If pinout with banks A to H,       */
#  define NB_BANK            8         /*   use banks A to H                 */
#  define BANK_D                       /*                                    */
#  define BANK_E                       /*                                    */
#  define BANK_F                       /*                                    */
#  define BANK_G                       /*                                    */
#  define BANK_H                       /*                                    */
#else                                  /* Otherwise,                         */
#ifdef BANKS_A_TO_G                    /* If pinout with banks A to G,       */
#  define NB_BANK            7         /*   use banks A to G                 */
#  define BANK_D                       /*                                    */
#  define BANK_E                       /*                                    */
#  define BANK_F                       /*                                    */
#  define BANK_G                       /*                                    */
#else                                  /* Otherwise,                         */
#ifdef BANKS_A_TO_F                    /* If pinout with banks A to F,       */
#  define NB_BANK            6         /*   use banks A to F                 */
#  define BANK_D                       /*                                    */
#  define BANK_E                       /*                                    */
#  define BANK_F                       /*                                    */
#else                                  /* Otherwise,                         */
#ifdef BANKS_A_TO_E                    /*   If pinout with banks A to E,     */
#  define NB_BANK            5         /*     use banks A to E               */
#  define BANK_D                       /*                                    */
#  define BANK_E                       /*                                    */
#else                                  /* Otherwise,                         */
#ifdef BANKS_A_TO_D                    /*   If pinout with banks A to D,     */
#  define NB_BANK            4         /*     use banks A to D               */
#  define BANK_D                       /*                                    */
#else                                  /* Otherwise,                         */
#ifdef BANKS_A_TO_C                    /*   If pinout with banks A to C,     */
#  define NB_BANK            3         /*     use banks A to C               */
#else                                  /* Otherwise,                         */
#  error Used banks not specified!     /*   ERROR: Used banks not specified! */
#endif                                 /*                                    */
#endif                                 /*                                    */
#endif                                 /*                                    */
#endif                                 /*                                    */
#endif                                 /*                                    */
#endif                                 /*                                    */

#define NB_PINS  (16 * NB_BANK)        /* 16 pins per bank                   */


  extern const UINT pinfun[NB_PINS]    ; /* Function mask per pin              */

/*
    1    Defines
    ____________
*/


/*
    2    Structures and typedefs
    ____________________________
*/


/*
   2.1 Structures de description drivers systemes (ROM)
   ----------------------------------------------------
*/

typedef struct                         /* Interface d'un driver systeme      */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* Vaut toujours 0 pour un driver sys */
                                       /*                                    */
    IWORD           (*init)()        ; /* Procedure d'initialisation         */
    IWORD           (*end )()        ; /* Procedure de finalisation          */
  END               Sdrv_desc        ; /* ---------------------------------- */


typedef struct                         /* Interface d'un device              */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *dev_name        ; /* Nom du device systeme (inutilise)  */
    const void      *dev_desc        ; /* Ad. structure description device   */
    const void      *dev_def         ; /* Ad. structure parametres devices   */
    const void      *drv_def         ; /* Ad. structure parametres driver/dev*/
  END               Dev_link         ; /* ---------------------------------- */
 

typedef struct                         /* Description d'un driver systeme    */
  BEGIN                                /* ---------------------------------- */
    const Sdrv_desc *sdrv_desc       ; /* Ad. interface  du  driver          */
    const Dev_link  *dev_link        ; /* Ad. interfaces des devices         */
    UCHAR           nb_dev           ; /* Nombre de devices dans sdev_link[] */
  END               Sdrv_link        ; /* ---------------------------------- */
 

/*
   2.2 Structures de description drivers/protocoles/services (ROM)
   ---------------------------------------------------------------
*/
 
#ifdef XDRV                            /* Nouvelle interface drivers.        */

typedef struct                         /* Interface entre couches            */
  BEGIN                                /* ---------------------------------- */
    IWORD           level            ; /* 1=driver, 2 et + = protocole       */
    CHAR            *name            ; /* Nom de la couche                   */

    IWORD           (*get_rctx)   () ; /* Retourne adresse contexte Req_ctx  */
    IWORD           (*get_info)   () ; /* Retourne adresse valeur demandee   */
                                       /*                                    */
    IWORD           (*connect)    () ; /* Demande connection sortante        */
    IWORD           (*listen)     () ; /* Demande connection entrante        */
    IWORD           (*disconnect) () ; /* Demande de deconnection            */
    IWORD           (*abort)      () ; /* Demande de rupture brutale         */
    IWORD           (*start)      () ; /* Demande de demarrage de flot       */
    IWORD           (*stop)       () ; /* Demande d'arret de flot            */
    IWORD           (*send)       () ; /* Demande d'emission                 */
    IWORD           (*receive)    () ; /* Demande de reception               */
    IWORD           (*setval)     () ; /* Demande d'ecriture de registres    */
    IWORD           (*getval)     () ; /* Demande de lecture de registres    */
    IWORD           (*rpc)        () ; /* Demande d'execution de commande    */
    IWORD           (*io)         () ; /* Demande d'entrees/sorties          */

  END               Tlcm_desc        ; /* ---------------------------------- */

#if(defined VM_ARM7)||(defined VM_X86GWOS) /* Version nouvelle intermediare. */

typedef struct                         /* Interface d'un driver/proto/serv   */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* 001:dcar 010:proto 011:ser 101:dblk*/

    UCHAR           *initdone        ; /* Ad. drapeau d'initialisation       */
    USHORT          *sessid          ; /* Ad. table identifiants de session. */
    USHORT          *con2vl          ; /* Ad. table association con-->vl     */
    UCHAR           *major           ; /* Ad variable major number           */
    UCHAR           *numdrv          ; /* Ad variable numero de driver       */
    IWORD           (*init   )()     ; /* Ad proc pour init specifique       */
    IWORD           (*reqevt )()     ; /* Ad proc pour evenements REQ_...    */
    IWORD           (*respevt)()     ; /* Ad proc pour evenements RESP_...   */
    IWORD           (*delcond)()     ; /* Ad proc pour supression conditions.*/
    IWORD           (*setindrep)()   ; /* Ad proc pour rerouter IND_REPORT   */

    IWORD           aut              ; /* Numero de l'automate sous IT       */
    const S_trans   *trans           ; /* Ad. table de transitions           */
    const USHORT    *lim             ; /* Ad. table des limites des etats    */
    USHORT          *etat            ; /* Ad. table des variabled'etats    */
    const USHORT    *nbvl            ; /* Taille en USHORTs de "etat"        */
    const USHORT    *nbcon           ; /* Taille en USHORTs de sessid/con2vl */
    const USHORT    *nbini           ; /* Nb de contextes d'empilement       */
    const Tlcm_desc *tlcm            ; /* Procedures d'interface             */
    void            *adr             ; /* Adresse "utilisateur"              */
  END               Drv_desc         ; /* ---------------------------------- */

#else                                  /* Version nouvelle finale.           */

typedef struct                         /* Interface d'un driver/proto/serv   */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* 001:dcar 010:proto 011:ser 101:dblk*/

    UCHAR           *initdone        ; /* Ad. drapeau d'initialisation       */
    IWORD           (*init   )()     ; /* Ad proc pour init specifique       */

    IWORD           aut              ; /* Numero de l'automate sous IT       */
    const S_trans   *trans           ; /* Ad. table de transitions           */
    const USHORT    *lim             ; /* Ad. table des limites des etats    */
    USHORT          *etat            ; /* Ad. table des variabled'etats    */
    const USHORT    *nbvl            ; /* Taille en USHORTs de "etat"        */
    const USHORT    *nbiod           ; /* Taille en USHORTs de sessid/con2vl */
    const USHORT    *nbmodd          ; /* Nb de contextes d'empilement       */
    const Tlcm_desc *tlcm            ; /* Procedures d'interface             */
    void            *adr             ; /* Adresse "utilisateur"              */
  END               Drv_desc         ; /* ---------------------------------- */

#endif                                 /* Specific GatewayOS / VMOS.         */

#else                                  /* Ancienne interface drivers.        */

typedef struct                         /* Interface d'un driver caractere    */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* 001:dcar 010:proto 011:ser 101:dblk*/

    UCHAR           *initdone        ; /* Ad. drapeau d'initialisation       */
    USHORT          *sessid          ; /* Ad. table identifiants de session. */
    USHORT          *con2vl          ; /* Ad. table association con-->vl     */
    UCHAR           *major           ; /* Ad variable major number           */
    UCHAR           *numdrv          ; /* Ad variable numero de driver       */
    IWORD           (*init   )()     ; /* Ad proc pour init specifique       */
    IWORD           (*reqevt )()     ; /* Ad proc pour evenements REQ_...    */
    IWORD           (*respevt)()     ; /* Ad proc pour evenements RESP_...   */
    IWORD           (*delcond)()     ; /* Ad proc pour supression conditions.*/
    IWORD           (*setindrep)()   ; /* Ad proc pour rerouter IND_REPORT   */

    IWORD           aut              ; /* Numero de l'automate sous IT       */
    const S_trans   *trans           ; /* Ad. table de transitions           */
    const USHORT    *lim             ; /* Ad. table des limites des etats    */
    USHORT          *etat            ; /* Ad. table des variabled'etats    */
    const USHORT    *nbvl            ; /* Nb total de voies logiques         */
    const USHORT    *nbcon           ; /* Nb de voies logiques "utilisateur" */
    const USHORT    *nbini           ; /* Nb de contextes d'initialisation.  */
    void            *adr             ; /* Adresse "utilisateur"              */
  END               Drv_desc         ; /* ---------------------------------- */

#endif                                 /* Fin du ifdef XDRV.                 */


typedef struct _pipe_desc              /* Interface support pipe des drivers */
  BEGIN                                /* ---------------------------------- */

    /* Interface a implementer pour la source ...............................*/

    void          (*get_info_src)()  ; /*                                    */
    IWORD         (*init_src)()      ; /*                                    */
    void          (*end_src)()       ; /*                                    */
    IWORD         (*input)()         ; /*                                    */
    IWORD         (*seek)()          ; /*                                    */
    void          (*free_src_data)() ; /*                                    */

    /* Interface a implementer pour le puits ................................*/

    void          (*get_info_sink)() ; /*                                    */
    IWORD         (*init_sink)()     ; /*                                    */
    void          (*end_sink)()      ; /*                                    */
    IWORD         (*output)()        ; /*                                    */

    /* Interface commune ....................................................*/

    void          (*event)()         ; /*                                    */
  END             Pipe_desc          ; /* ---------------------------------- */


typedef struct                         /* Description d'un driver caractere  */
  BEGIN                                /* ---------------------------------- */
    const Drv_desc  *drv_desc        ; /* Ad. interface  du  driver          */
    const Dev_link  *dev_link        ; /* Ad. liste d'interfaces des devices */
    UCHAR           nb_dev           ; /* Nombre de devices dans dev_link[]  */
    const Pipe_desc *pipe            ; /* Ad. interface pipe                 */
  END               Drv_link         ; /* ---------------------------------- */
 
 
/*
   2.3 Structure de description d'un board (ROM)
   ---------------------------------------------
*/
 
typedef struct                         /* Description d'un board             */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *board_name      ; /* Nom du board                       */
    const Drv_link  *const* drv_link ; /* Ad. tab Ad. de drivers/proto/serv  */
  END               Board_link       ; /* ---------------------------------- */
 

/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of DRVMIO_H.                   */
