/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/drv_led.h"             */
/*  Constants and definitions for LED driver.                                */
/*                                                                           */
/*  Author : JYA                        Last modification : 06/08/2018       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
            1.1  Interface haute - Numeros des registres du driver LED
            1.2  Interface haute - Valeurs du tag STATE
            1.3  Interface haute - Valeurs du tag COLOR
            1.4  Interface haute - Valeurs du tag CMD
         2  Structures and typedefs
            2.1  Description d'une couche basse du driver LED - Led_desc
            2.2  Description d'un contexte de controleur de LEDs - Ledctrl_ctx
            2.3  Description d'un contexte de LED - Led_ctx
         3  Public variable
         4  Prototypes of public procedures


*/


#ifndef DRV_LED_H                      /* If this file is not already        */
#define DRV_LED_H                      /* included, include it.              */


/*
    1    Defines
    ____________
*/


/*
    1.1 Interface haute - Numeros des registres du driver LED
    ---------------------------------------------------------
*/



#ifdef XDRV

#define SZPATT              128        /* Taille en octets de PATTERN        */
                                       /* Doit etre multiple de 4            */

/* Nombres de registres pour les tags TYPE, NAME, PATTERN et RCUPATT ........*/

#define NBRTYPE               1        /* TYPE     1 UINTS    4 octets       */
#define NBRNAME               2        /* NAME     2 UINTS    8 octets       */
#define NBRPATT     (SZPATT/ZI)        /* PATTERN 32 UINTS  128 caracteres   */

/* Numeros des registres associes aux controlleurs de LEDs ..................*/

#define NRTYPE                0        /* chaine TYPE      (1  UINTs)        */
#define NRNAME                1        /* chaine NAME      (2  UINTs)        */
#define NRNBLEDS              3        /* entier NBLED     (1  UINT)         */
#define NRDEVNUM              4        /* entier DEVNUM    (1  UINT)         */

/* Numeros des registres associes au leds ...................................*/

#define NRLEDNUM              5        /* entier LEDNUM    (1  UINT)         */
#define NRLEDNAME             6        /* entier LEDNAME   (2  UINT)         */
#define NRCOLOR               8        /* entier COLOR     (1  UINT)         */
#define NRSTATE               9        /* entier STATE     (1  UINT)         */
#define NRVLRCU              10        /* entier VLRCU     (1  UINT)         */
#define NRPATTERN            11        /* chaine PATTERN   (32 UINTs)        */
#define NRRCUPATT            43        /* chaine RCUPATT   (32 UINTs)        */
#define NRPSTACK             75        /* entier PSTACK    (1  UINT)         */
#define NRLEDCMD             76        /* entier CMD       (1  UINT)         */

/* Tailles en UINTs des registres controlleurs et leds ......................*/

#define NBREGCTR              5        /* Taille du tableau de registres     */
                                       /* Registres  0 a 4 inclus            */
#define NBREGLED             72        /* Taille du tableau de registres     */
                                       /* Registres  5 a 52 inclus           */
#else /* nXDRV */

#define SZPATT               80        /* Taille en octets de PATTERN        */
                                       /* Doit etre multiple de 4            */
/* Nombres de registres pour les tags TYPE, NAME, PATTERN et RCUPATT ........*/

#define NBRTYPE               3        /* TYPE     3 UINTS   12 octets       */
#define NBRNAME               3        /* NAME     3 UINTS   12 octets       */
#define NBRPATT     (SZPATT/ZI)        /* PATTERN 20 UINTS   80 caracteres   */

/* Numeros des registres associes aux controlleurs de LEDs ..................*/

#define NRTYPE                0        /* chaine TYPE      (3  UINTs)        */
#define NRLEDNAME             3        /* chaine NAME      (3  UINTs)        */
#define NRNBLED               6        /* entier NBLED     (1  UINT)         */

/* Numeros des registres associes au leds ...................................*/

#define NRCOLOR               7        /* entier COLOR     (1  UINT)         */
#define NRSTATE               8        /* entier STATE     (1  UINT)         */
#define NRVLRCU               9        /* entier VLRCU     (1  UINT)         */
#define NRPATTERN            10        /* chaine PATTERN   (20 UINTs)        */
#define NRRCUPATT            30        /* chaine RCUPATT   (20 UINTs)        */
#define NRPSTACK             50        /* entier PSTACK    (1  UINT)         */
#define NRLEDCMD             51        /* entier CMD       (1  UINT)         */

/* Tailles en UINTs des registres controlleurs et leds ......................*/

#define NBREGCTR              7        /* Taille du tableau de registres     */
                                       /* Registres  0 a 6 inclus            */
#define NBREGLED             45        /* Taille du tableau de registres     */
                                       /* Registres  7 a 51 inclus           */
#endif /* XDRV */

/*
   1.2 Interface haute - Valeurs du tag STATE
   ------------------------------------------

   On notera que ces deu constantes peuvent aussi servir de parametrre d'entree
   a la procedure de bas niveau "setLED_xyz" (parametre state)
*/

#define ST_OFF                0        /* Led eteinte                        */
#define ST_ON                 1        /* Led allumee                        */

/*
   1.3 Interface haute - Valeurs du tag COLOR
   ------------------------------------------
*/
#define C_GREEN               0        /* Couleur verte                      */
#define C_YELLOW              1        /* Couleur jaune                      */
#define C_RED                 2        /* Couleur rouge                      */
#define C_BLUE                3        /* Couleur bleue                      */

/*
   1.4 Interface haute - Valeurs du tag CMD
   ----------------------------------------
*/
#define CMD_PUSH              0        /* Commande PUSH                      */
#define CMD_POP               1        /* Commande POP                       */
#define CMD_POPALL            2        /* Commande POPALL                    */


/*
    2    Structures and typedefs
    ____________________________
*/

/*
   2.1  Description d'une couche basse du driver LED - Led_desc
   ------------------------------------------------------------
*/

#ifdef XDRV

typedef struct                         /* Adresses proceduresde bas niveau  */
  BEGIN                                /* ---------------------------------  */
    void      (*info)()              ; /* Recuperation des infos             */
    void      (*set )()              ; /* Definit l'etat de la LED           */
  END         Led_desc               ; /* ---------------------------------- */

#else

typedef struct                         /* Adresses proceduresde bas niveau  */
  BEGIN                                /* ---------------------------------  */
    void      (*setLED)()            ; /* Definit l'etat de la LED           */
    void      (*infoLED)()           ; /* Recuperation des infos             */
  END         Led_desc               ; /* ---------------------------------- */

#endif


/*
   2.2  Description d'un contexte de controleur de LEDs - Ledctrl_ctx
   ------------------------------------------------------------------
*/

#ifdef XDRV

typedef struct                         /* Contexte d'un controleur de KEDs   */
  BEGIN                                /* ---------------------------------- */
    Req_ctx   rctx                   ; /* IOD du controleur                  */
    UCHAR     fled                   ; /* Idx du contexte de sa 1ere LED.    */
    UCHAR     nbleds                 ; /* Nombre de LEDs rattachees au ctrl  */
    UINT      reg[NBREGCTR]          ; /* Registres NRTYPE NRNAME NRNBLED    */
  END         Ledctrl_ctx            ; /* ---------------------------------- */
     
#else

typedef struct                         /* Contexte d'un controleur de KEDs   */
  BEGIN                                /* ---------------------------------- */
    UINT      iod                    ; /* IOD du controleur                  */
    UCHAR     fled                   ; /* Idx du contexte de sa 1ere LED.    */
    UCHAR     nbleds                 ; /* Nombre de LEDs rattachees au ctrl  */
    UINT      reg[NBREGCTR]          ; /* Registres NRTYPE NRNAME NRNBLED    */
  END         Ledctrl_ctx            ; /* ---------------------------------- */
     
#endif


/*
   2.3  Description d'un contexte de LED - Led_ctx 
   -----------------------------------------------

   A Text pattern has a maximum size of SZPATT characters. The smallest item
   it may contain, in terms of character size, is "ON:0," so 5 characters.
   So a text pattern may include a maximum of SZPATT/5 items. The maximum
   size of a compiled item is 3 bytes, therefore a compiled pattern size
   cannot exceed L_RUBAN = (SZPATT / 5) * 3 bytes
*/

#define L_RUBAN    ((SZPATT/5)*3)      /* Maximum size of a compiled pattern */
#define T_PILE                  4      /* Max empilable par l'utilisateur    */
#define T_RCU                  32      /* Max RCU associables a une LED      */

#ifdef XDRV

typedef struct                         /* Context for one LED                */
  BEGIN                                /* ---------------------------------- */
    UINT        iodsub               ; /* Sub-channel IOD for that LED       */
    UCHAR       dev                  ; /* Device number of the controller    */
    UCHAR       ssc                  ; /* Our sub-channel number             */
    UCHAR       iled                 ; /* Index in "led_ctx[]"               */
    USHORT      myvl                 ; /* AUD_LED logical way number         */
    void        (*set)()             ; /* Low level procedure address        */
                                       /*                                    */
    UINT        reg[NBREGLED]        ; /* Registers for this LED             */
    UCHAR       pattern              ; /* Compiled code of  PATTERN          */
    UCHAR       rcupatt              ; /* Compiled code of  RCUPATT          */
                                       /*                                    */
    UCHAR       progs[T_PILE+1]      ; /* Stack of compiled patterns         */
    UCHAR       press                ; /* 1 if between PRESS and RELEASE     */
    UCHAR       iref                 ; /* Ref of program byte string         */
    USHORT      ioff                 ; /* Offset of next executed instruction*/
    INT         idto                 ; /* Current time-out identifier        */
                                       /*                                    */
    UINT        vlrcu                ; /* Bitfield of associated RCU's       */
    UINT        rtercu[T_RCU]        ; /* RCU->LED route identifiers         */
                                       /*                                    */
  END           Led_ctx              ; /* ---------------------------------- */


#else

typedef struct                         /* Contexte d'une LED                 */
  BEGIN                                /* ---------------------------------- */
    UINT        iodsub               ; /* IOD de sous-canal de la LED        */
    UCHAR       dev                  ; /* Numero de device du controleur     */
    UCHAR       ssc                  ; /* Notre numero de sous-canal         */
    UCHAR       iled                 ; /* Indice dans "led_ctx[]"            */
    USHORT      myvl                 ; /* Numero de VL de AUT_LED            */
    void        (*setLED)()          ; /* Ad proc de bas niveau              */
                                       /*                                    */
    UINT        reg[NBREGLED]        ; /* Registres relatifs a cette LED     */
    UCHAR       pattern[L_RUBAN]     ; /* Forme compilee de PATTERN          */
    UCHAR       rcupatt[L_RUBAN]     ; /* Forme compilee de RCUPATT          */
                                       /*                                    */
    UCHAR       progs[T_PILE+1]        /* Pile des patterns compiles.        */
                     [L_RUBAN ]      ; /* Nb octets d'un pattern compile     */
    UCHAR       press                ; /* 1 si entre PRESS et RELEASE        */
    const UCHAR *ptri                ; /* Adr prochaine instruction a eecuter*/
    INT         idto                 ; /* Id de la tempo courante.           */
                                       /*                                    */
    UINT        vlrcu                ; /* Champ de bits des VL RCU associees */
    UINT        rtercu[T_RCU]        ; /* Identifiants des routes RCU->LED   */
                                       /*                                    */
  END           Led_ctx              ; /* ---------------------------------- */

#endif


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of DRV_LED_H.                  */
