/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "stm32m3/src/mcu_desc.h"        */
/*  Constants and definitions for ...                                        */
/*                                                                           */
/*  Author : ADE                        Last modification : 11/05/2018       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =========================================================

         This file contains defines and constants relative to the registers of 
the chipset STM32L152.


         This module is based on the documents:

         - 1: "RM0038 Reference manual" (file "stm32l1xx_pm.pdf"), revision 15 
           (september 2017)

         - 2: "STM32L151xE STM32L152xE" (file "stm32l15x_hw.pdf"), revision 9 
           (august 2017)


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


===============================================================================
         If this file is modified, the file "mcu_desc_l152.c" has to be 
modified too.
===============================================================================
*/


#ifndef STM32L152_H                    /* If this file is not already        */
#define STM32L152_H                    /* included, include it.              */




/*
    1    Defines
    ____________
*/

/* Number of specific drivers (when several ones) ...........................*/

#define NUM_TMRS            12         /* Number of timers                   */
#define NUM_GPIO             8         /* Number of GPIOs                    */
#define NUM_UART             5         /* Number of USARTs/UARTs             */
#define NUM_SPI              3         /* Number of SPIs                     */
#define NUM_I2C              2         /* Number of I2Cs                     */
#define NUM_DMA              2         /* Number of DMAs                     */
#define NUM_EXTI            16         /* Number of extenal ITs              */



/* "System" numbers of the peripherals ......................................*
 * Each peripheral has a "system" number. This number is the bit shift in    *
 * the reset and clock enable registers.                                     *
 * Example: UART2_SN = 81 = 2 * 32 + 17                                      *
 * The reset bit for this UART is (&rccregs.ahbrst + 2), bit 1 << 17.        *
 * These defines are based on the document 1, chapters 6.3.5 AHB peripheral  *
 * reset register (RCC_AHBRSTR) to 6.3.13 APB1 peripheral clock enable in    *
 * low-power mode register (RCC_APB1LPENR).                                  */

#define GPIOA_SN             0         /* \                                  */
#define GPIOB_SN             1         /* |                                  */
#define GPIOC_SN             2         /* |                                  */
#define GPIOD_SN             3         /* |  GPIO                            */
#define GPIOE_SN             4         /* | (A..H)                           */
#define GPIOF_SN             5         /* |                                  */
#define GPIOG_SN             6         /* |                                  */
#define GPIOH_SN             7         /* /                                  */
#define CRC_SN              12         /* Cyclic redundancy check            */
#define FLASH_SN            15         /* Flash                              */
#define SRAM_SN             16         /* SRAM clock                         */
#define DMA1_SN             24         /* DMA1                               */
#define DMA2_SN             25         /* DMA2                               */
#define AES_SN              27         /* Advanced encryption standard       */
                                       /* hardware accelerator               */
#define FSMC_SN             30         /* Flexible Memory Controller         */

#define SYSCFG_SN           32         /* System configuration               */
#define TMR9_SN             34         /* TIM9                               */
#define TMR10_SN            35         /* TIM10                              */
#define TMR11_SN            36         /* TIM11                              */
#define ADC1_SN             41         /* Analog-Digital Converter           */
#define SDIO_SN             43         /* SD Card I/O                        */
#define SPI1_SN             44         /* SPI1                               */
#define UART1_SN            46         /* USART1                             */

#define TMR2_SN             64         /* TIM2                               */
#define TMR3_SN             65         /* TIM3                               */
#define TMR4_SN             66         /* TIM4                               */
#define TMR5_SN             67         /* TIM5                               */
#define TMR6_SN             68         /* TIM6                               */
#define TMR7_SN             69         /* TIM7                               */
#define LCD_SN              73         /* Liquid Crystal Display             */
#define WWDG_SN             75         /* Window watchdog                    */
#define SPI2_SN             78         /* SPI2                               */
#define SPI3_SN             79         /* SPI3                               */
#define UART2_SN            81         /* USART2                             */
#define UART3_SN            82         /* USART3                             */
#define UART4_SN            83         /* UART4                              */
#define UART5_SN            84         /* UART5                              */
#define I2C1_SN             85         /* I2C1                               */
#define I2C2_SN             86         /* I2C2                               */
#define USB_SN              87         /* USB                                */
#define PWR_SN              92         /* Power                              */
#define DAC_SN              93         /* DAC                                */
#define COMP_SN             95         /* Analog Comparator                  */



/* Used banks ...............................................................*/

//#ifdef BANKS_A_TO_H                    /* If pinout with banks A to H,       */
//#  define NB_BANK            8         /*   use banks A to H                 */
//#  define BANK_D                       /*                                    */
//#  define BANK_E                       /*                                    */
//#  define BANK_F                       /*                                    */
//#  define BANK_G                       /*                                    */
//#  define BANK_H                       /*                                    */
//#else                                  /* Otherwise,                         */
//#ifdef BANKS_A_TO_G                    /* If pinout with banks A to G,       */
//#  define NB_BANK            7         /*   use banks A to G                 */
//#  define BANK_D                       /*                                    */
//#  define BANK_E                       /*                                    */
//#  define BANK_F                       /*                                    */
//#  define BANK_G                       /*                                    */
//#else                                  /* Otherwise,                         */
//#ifdef BANKS_A_TO_F                    /* If pinout with banks A to F,       */
//#  define NB_BANK            6         /*   use banks A to F                 */
//#  define BANK_D                       /*                                    */
//#  define BANK_E                       /*                                    */
//#  define BANK_F                       /*                                    */
//#else                                  /* Otherwise,                         */
//#ifdef BANKS_A_TO_E                    /*   If pinout with banks A to E,     */
//#  define NB_BANK            5         /*     use banks A to E               */
//#  define BANK_D                       /*                                    */
//#  define BANK_E                       /*                                    */
//#else                                  /* Otherwise,                         */
//#ifdef BANKS_A_TO_D                    /*   If pinout with banks A to D,     */
//#  define NB_BANK            4         /*     use banks A to D               */
//#  define BANK_D                       /*                                    */
//#else                                  /* Otherwise,                         */
//#ifdef BANKS_A_TO_C                    /*   If pinout with banks A to C,     */
//#  define NB_BANK            3         /*     use banks A to C               */
//#else                                  /* Otherwise,                         */
//#  error Used banks not specified!     /*   ERROR: Used banks not specified! */
//#endif                                 /*                                    */
//#endif                                 /*                                    */
//#endif                                 /*                                    */
//#endif                                 /*                                    */
//#endif                                 /*                                    */
//#endif                                 /*                                    */
//
//#define NB_PINS  (16 * NB_BANK)        /* 16 pins per bank                   */



/* Pin functions ............................................................*/

#define FGPIO         (1 <<  0)        /* Bit 0  -> fct GPIO                 */




/*
    2    Structures and typedefs
    ____________________________
*/



/*
    3    Public variables
    _____________________
*/

/* "System" numbers .........................................................*/

extern const IWORD tmr_sn[NUM_TMRS]  ; /* "System" number of the timers      */
extern const IWORD gpio_sn[NUM_GPIO] ; /* "System" number of the GPIOs       */
extern const IWORD uart_sn[NUM_UART] ; /* "System" number of the USARTs/UARTs*/



/* Interrupt numbers ........................................................*/

extern const IWORD nbIRQ               ; /* Number of ITs                    */

extern const IWORD numit_tmr[NUM_TMRS] ; /* IT numbers of the timers         */
extern const IWORD numit_asy[NUM_UART] ; /* IT numbers of the USARTs/UARTs   */
extern const IWORD numit_adc           ; /* IT number of the ADC             */

extern const IWORD numit_dma1[7]       ; /* IT numbers of the DMA1 channels  */
extern const IWORD numit_dma2[5]       ; /* IT numbers of the DMA2 channels  */
extern const IWORD *numit_dma[NUM_DMA] ; /* IT numbers of the DMA channels   */

extern const IWORD numit_exti[NUM_EXTI]; /* IT numbers of the external ITs   */

#ifdef NOT_USED
extern const IWORD numit_spi[NUM_SPI]  ; /* IT numbers of the SPIs           */

extern const IWORD numit_wwdg          ; /* IT number of the window watchdog */
extern const IWORD numit_pvd           ; /* IT number of the PVD through EXTI*/
                                         /* line 16 detection                */
extern const IWORD numit_tamper_stamp  ; /* IT number of the tamper, LSECSS  */
                                         /* and time stamp through EXTI line */
                                         /* 19                               */
extern const IWORD numit_rtc_wkup      ; /* IT number of the RTC wakeup      */
                                         /* through EXTI line 20             */
extern const IWORD numit_flash         ; /* IT number of the flash           */
extern const IWORD numit_rcc           ; /* IT number of the RCC             */
extern const IWORD numit_usb_hp        ; /* IT number of the USB high priorit*/
extern const IWORD numit_usb_lp        ; /* IT number of the USB low priority*/
extern const IWORD numit_dac           ; /* IT number of the DAC             */
extern const IWORD numit_comp_ca       ; /* IT number of the comparator      */
                                         /* wakeup through EXTI lines 21 and */
                                         /* 22 / channel acquisition         */
extern const IWORD numit_lcd           ; /* IT number of the LCD             */
extern const IWORD numit_i2c1_ev       ; /* IT number of the I2C1 event      */
extern const IWORD numit_i2c1_er       ; /* IT number of the I2C1 error      */
extern const IWORD numit_i2c2_ev       ; /* IT number of the I2C2 event      */
extern const IWORD numit_i2c2_er       ; /* IT number of the I2C2 error      */
extern const IWORD numit_rtc_alarm     ; /* IT number of the RTC alarms A and*/
                                         /* B through EXTI line 17           */
extern const IWORD numit_usb_fs_wkup   ; /* IT number of the USB device FS   */
                                         /* wakeup through EXTI line 18      */
extern const IWORD numit_aes           ; /* IT number of the AES global      */
extern const IWORD numit_comp_acq      ; /* IT number of the comparator      */
                                         /* channel acquisition              */
#endif /* NOT_USED */



/* Basic addresses of the peripherals .......................................*/

extern volatile Syscfg_t *const syscfg    ; /* System configuration (APB2)   */
extern volatile Rcc_ctrl *const rcc       ; /* Reset & clock control (AHB)   */
extern volatile Tmr *const tmrs[NUM_TMRS] ; /* Basic address of the timers   */
extern volatile Gpio *const gpio[NUM_GPIO]; /* Basic address of the GPIOs    */
extern volatile Asc_t* const asy[NUM_UART]; /* Basic address of the USARTs/UA*/
extern volatile Adc_t *const adc          ; /* Analog Digital Converter (APB2*/
extern volatile Dac_t *const dac          ; /* Digital Analog Converter (APB1*/
extern volatile Dma_t *const dma[NUM_DMA] ; /* Basic address of the DMAs     */
extern volatile Exti_t *const exti        ; /* External interrupt (APB2)     */

#ifdef NOT_USED
extern volatile Spi_t *const spi[NUM_SPI] ; /* Basic address of the SPIs     */
extern volatile UINT *const i2c[NUM_I2C]  ; /* Basic address of the I2Cs     */

extern volatile UINT *const lcd           ; /* LCD (APB1)                    */
extern volatile UINT *const rtc           ; /* Real-time clock (APB1)        */
extern volatile UINT *const wwdg          ; /* Window watchdog (APB1)        */
extern volatile UINT *const iwdg          ; /* Independant watchdog (APB1)   */
extern volatile UINT *const usbfs         ; /* USB device FS (APB1)          */
extern volatile UINT *const usbfsram      ; /* USB device FS SRAM (APB1)     */
extern volatile UINT *const pwr           ; /* Power (APB1)                  */
extern volatile UINT *const comp          ; /* Analog Comparator (APB1)      */
extern volatile UINT *const ri            ; /* Routing Interface (APB1)      */
extern volatile UINT *const opamp         ; /* Operational Amplifier (APB1)  */

extern volatile UINT *const sdio          ; /* SD Card I/O (APB2)            */

extern volatile UINT *const crc           ; /* Cylindric Redundancy Check    */
                                            /* (ETH) (AHB)                   */
extern volatile UINT *const flash         ; /* Flash (AHB)                   */
extern volatile UINT *const aes           ; /* Advanced encryption standard  */
                                            /* hardware accelerator (AHB)    */
extern volatile UINT *const fsmc          ; /* Flexible static memory        */
                                            /* controller (AHB)              */
#endif /* NOT_USED */



/* Function mask per pin ....................................................*/

//extern const UINT pinfun[NB_PINS]    ; /* Function mask per pin              */




/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of STM32L152_H                 */

