/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     Fichier "stm32/include/xauto.h"      */
/*  Constants and definitions for automatons handling.                       */
/*                                                                           */
/*  Author : JYA                        Last modification : 15/01/2014       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/

/*
 * ATTENTION : Dans cette version de "auto.h", tous les automates VMIO ont
 *             ete renumerotes pour faire la place a AUT_RESOLVE a la
 *             position 128.
 */

#ifndef AUTO_H                         /* Debut compilation conditionnelle.  */
#define AUTO_H                         /* Identificateur de cet include.     */

/*
   Ce fichier contient les definitions des numeros d'automates, ainsi que
   celles des numeros d'evenements.

   On a actuellement deux "tranches" de numeros d'automates :

   - Les numeros 0 a 127 sont ceux des automates du VMOS, c'est-a-dire des
     automates executes par "moteur.c"

   - Les numeros 128 a 255 sont ceux des automates du VMIO, c'est-a-dire des
     automates executes par "motrit.c". L'automate numero 128 est TOUJOURS
     et ETERNELLEMENT reserve a AUT_RESOLVE.

   NOTE IMPORTANTE: Les numeros des automates du VMOS servent d'indice dans
   les  trois tables "anom", "enom" et "nnom" situees dans vmos/vmk2.c.
   A chaque fois que l'on ajoute, retire un automate, ou que l'on change les
   valeurs des numeros, il FAUT modifier ces trois tables en consequence. Si
   on ne le fait pas, non seulement les traces du moteur sont fausses, mais en
   plus on peut generer des ecrasements memoire. Le paresseux qui trouve cela
   trop fatiguant n'a pas le droit de modifier le present fichier, sous peine
   de passer par la fenetre, qui peut, le cas echeant, ne pas se trouver
   ouverte a cet instant.

   Les "tranches" de numeros d'evenements sont les suivantes :

   - Les evenements de 0 a 299 sont des codes utilisables en PanTalk, ils
     possedent des menemoniques. On y trouve les codes "generaux" du VMOS,
     ainsi que les codes "generaux" du VMIO.

   - Les evenements de 300 a 499 sont les codes "generaux" du VMIO. Ils
     possedent des mnemoniques, aux cas ou certains "remontent" jusqu'au VMOS.
     Mais la majorite de ces mnemoniques ne seront jamais utilises.

   - Les evenements a partir de 1024 sont les codes d'evenements "prives" des
     automates du VMOS. Ces codes sont definis dans le present fichier, ce qui
     signifie qu'ils ne sont pas des mnemoniques Pantalk Par convention, on
     reserve pour chaque automate du VMOS une trance de 32 numeros consecutifs.
     La premiere tranche ainsi reservee est la tranche 1024 a 1024+31 = 1055,
     et est attribuee a l'automate "script" AUTSCR_EXE (0)

   - Les evenements de code superieur ou egal a 10000 sont reserves aux
     applications PanTalk. Les codes d'evenements etant des USHORT, la plus
     grande valeur est 32767. Les codes negatifs sont interdits.

NOTES :
*** Les codes des evenements TO_ devraient etre des codes "locaux, definis
    dans "auto.h" et pas ici.

*/

/*===========================================================================*
 *                     PENSEZ A TENIR A JOUR VMK2.C                          *
 *===========================================================================*/

#define ALL_EVENT           -1         /* N'importe quel evenement           */


/*****************************************************************************
 * Numeros des automates du VMOS                                             *
 * -----------------------------                                             *
 *                                                                           *
 * Ces numeros d'automates sont compris entre 0 et 127                       *
 *                                                                           *
 * Pour chaque numero d'automate, on trouve a la suite les codes de ses      *
 * evenements "prives". Le premier de ces codes est toujours egal a          *
 * 1024 + 32 * numero de l'automate. De ce fait, on dispose de 32 codes      *
 * pour chacun des automates                                                 *
 *                                                                           *
 *****************************************************************************/

/* Procedure "timerto" ......................................................
   Pour permettre la purge sans risque d'erreur des TO, une valeur
   particuliere des champs "emet" des evenements est reservee aux TO du
   VMK. Il s'agit de la valeur 0
*/

#define TIMERTO            0           /* vmos/mosteur/vmk1.c, timerto"      */


/* Automate Interpreteur de Scripts .........................................*/

#define AUTSCR_EXE         1           /* src/executif/scr_auto.c            */
                                       /* Evenements prives:                 */
#define SCR_EXE_CONT       1056        /* code evt script -> execution       */
#define SCR_EXE_BREAK      1057        /* code evt script -> interruption    */
#define CND_EXE_LOAD       1058        /* condition script -> chargement     */
#define SCR_EXE_SCHED      1059        /* code evt script -> scheduler       */


/* Automates claviers ...................................................... */

#define AUTTKBD            2           /* src/moteur/autkbd.c                */
                                       /* Evenements prives:                 */
#define KEY_TEMPO          1088        /* Evt de temporisation.              */

#define AUTKBD             3           /* src/moteur/autkbd.c                */
                                       /* Evenements prives:                 */
#define KEY_RELEASE_R      1120        /* Touche relachee                    */


/* Automate de gestion des evenements souris ................................*/

#define AUTMOUSE           4           /* src/moteur/autmse.c                */
                                       /* Evenements prives:                 */
#define MOUSE_TEMPO        1152        /* Evt fin de tempo.                  */
#define MOUSE_INIT         1153        /* Evt 1er pression sur bouton souris */
#define MOUSE_STOP         1154        /* Evt retour a l'etat 0.             */
#define MOUSE_BREAK        1155        /* Evt attente de fin de move_cursor()*/
#define MOUSE_RETURN       1156        /* Evt fin du move_cursor().          */


/* Automate TIME ............................................................*/

#define AUT_TIME           5           /* src/moteur/auttime.c               */

#define TIME_WATCHDOG      1184        /*                                    */


/* Automate de gestion du chargement ........................................*/

#define AUTHLOAD           6           /* src/memoire/setelt.c               */
                                       /* Evenements prives:                 */
#define HLOAD_LOAD         1216        /* Lancer      le chargement          */
#define HLOAD_DOWNLOAD     1217        /* Attendre    le telechargement      */
#define HLOAD_SOLVE_REF    1218        /* Attendre    le chargement des ref. */
#define HLOAD_INIT         1219        /* Attendre    l'initialisation       */
#define HLOAD_WAIT_LOAD    1220        /* Attendre    le passage a utilisable*/
#define HLOAD_ERROR        1221        /* Erreur      de chargement          */
#define HLOAD_CONT         1222        /* Continuer   le chargement          */
#define HLOAD_WAIT         1223        /* Interrompre le chargement          */
#define HLOAD_CHECK_EXE    1224        /* Verifier    si executable          */


/* Automate de gestion des telechargements ..................................*/

#define AUT_DOWNLOAD       7           /* src/file/download.c                */
                                       /* Evenements prives:                 */
#define BLOC_RECEIVED      1248        /* Bloc recu                          */
#define VOLUME_CHANGE      1249        /* Volume a change                    */
#define VOLUME_END         1250        /* Volume n'est plus diffuse          */
#define DOWNLOAD_ERROR     1251        /* Erreur de chargement               */
#define DOWNLOAD_CONT      1252        /* Continuer un autre chargement      */


/* Automate telechargement MHEG5, base sur DSMCC ............................*/

#define AUT_DSMCC_MPEG2    8           /* src/file/dsmcc.c                   */
                                       /* Evenements prives:                 */
#define MHEG_TIMEOUT       1280        /* Fin de tempo sur reception         */
#define MHEG_ERROR         1281        /* Erreur dans ce qui a ete recu      */
#define MHEG_FIL_FOUND     1282        /* Fin de la recherche                */
#define MHEG_DII_FOUND     1283        /* Fin de demande de DII              */
#define MHEG_WAIT          1284        /* Attente de fin d'un autre chargt   */
#define DSMCC_SETDMX       1285        /* Commande de configuartion demux.   */
#define C_DSMCC_LIB        1286        /* Condition: liberer le filtre demux */
#define C_DSMCC_ERROR      1287        /* Condition: erreur allocation filtre*/


/* Automate vide ........................................................... */

#define AUT_EMPTY          9           /*                                    */


/* Automates DF ............................................................ */

#define AUT_DF             10          /* src/file/df.c                      */


/* Automate AUT_TASK ....................................................... */

#define AUT_TASK           11          /* vmos/moteur/vmk.c                  */

#define RUN_TASK           1376        /* Lance une tache.                   */
#define KILL_TASK          1377        /* Tue   une tache.                   */
#define CLOSE_TASK         1378        /* Fin d'une tache.                   */
#define TASK_TIMER         1379        /* Echeance d'un timer de tache.      */
#define TASK_SIGNAL        1380        /* Un semaphore devient disponible.   */
#define TASK_EVT0          1381        /* 1er   evenement inter-taches.      */
#define TASK_EVT1          1382        /* 2nd   evenement inter-taches.      */
#define TASK_EVT2          1383        /* 3eme  evenement inter-taches.      */
#define TASK_EVT3          1384        /* 4eme  evenement inter-taches.      */
#define TASK_EVT4          1385        /* 5eme  evenement inter-taches.      */
#define TASK_EVT5          1386        /* 6eme  evenement inter-taches.      */
#define TASK_EVT6          1387        /* 7eme  evenement inter-taches.      */
#define TASK_EVT7          1388        /* 8eme  evenement inter-taches.      */
#define TASK_EVT8          1389        /* 9eme  evenement inter-taches.      */
#define TASK_EVT9          1390        /* 10eme evenement inter-taches.      */
#define TASK_EVT10         1391        /* 11eme evenement inter-taches.      */
#define TASK_EVT11         1392        /* 12eme evenement inter-taches.      */
#define TASK_EVT12         1393        /* 13eme evenement inter-taches.      */
#define TASK_EVT13         1394        /* 14eme evenement inter-taches.      */
#define TASK_EVT14         1395        /* 15eme evenement inter-taches.      */
#define TASK_EVT15         1396        /* 16eme evenement inter-taches.      */
#define TASK_EVT16         1397        /* 17eme evenement inter-taches.      */
#define TASK_EVT17         1398        /* 18eme evenement inter-taches.      */
#define TASK_EVT18         1399        /* 19eme evenement inter-taches.      */
#define TASK_EVT19         1400        /* 20eme evenement inter-taches.      */
#define TASK_EVT20         1401        /* 21eme evenement inter-taches.      */
#define TASK_EVT21         1402        /* 22eme evenement inter-taches.      */
#define TASK_EVT22         1403        /* 23eme evenement inter-taches.      */
#define TASK_EVT23         1404        /* 24eme evenement inter-taches.      */
#define TASK_EVT24         1405        /* 25eme evenement inter-taches.      */
#define TASK_EVT25         1406        /* 26eme evenement inter-taches.      */
#define TASK_EVT26         1407        /* 27eme evenement inter-taches.      */
#define TASK_EVT27         1408        /* 28eme evenement inter-taches.      */
#define TASK_EVT28         1409        /* 29eme evenement inter-taches.      */
#define TASK_EVT29         1410        /* 30eme evenement inter-taches.      */
#define TASK_EVT30         1411        /* 31eme evenement inter-taches.      */
#define TASK_EVT31         1412        /* 32eme evenement inter-taches.      */


/* Automate de gestion de la tables des ON en V3 ............................*/

#define AUT_PTLKV3         12          /* numero automate                    */

#define PTLKV3_OFF         1408        /* Effacement d'un module             */


/* Automate  AUT_DVBSTL des sous-titres DVB .................................*/

#define AUT_DVBSTL         13          /* src/ttx/dvbstl.c                   */

#define DVBSTL_TO          1440        /* Evenement de temporisation         */
#define DVBSTL_START       1441        /* Evenement de demarrage             */
#define DVBSTL_STOP        1442        /* Evenement d'arret                  */
#define DVBSTL_PCR_TO      1443        /* Evenement temporisation PCR        */

/* Automate de selection de slot de controle d'acces. .......................*/

#define AUT_CA_API         14          /* src/acces/ac_api.c                 */
                                       /*                                    */
#define CA_STM_ON          1472        /* Debut d'utilisation du stream.     */
#define CA_STM_UPD         1473        /* Modification de la PMT.            */
#define CA_STM_OFF         1474        /* Fin d'utilisation du stream.       */
#define CA_STM_STAT        1475        /* Nouveau statut du stream pour le CA*/
#define CA_ACTIVE          1476        /* Module CA externe insere/CA actif. */
#define CA_INACTIVE        1477        /* Module CA extrn retire/CA desactive*/
#define CA_SC_INIT         1478        /* Initialisation d'1 lecteur de carte*/
#define CA_SC_IN           1479        /* Smart Card reconnue (slot CA).     */
#define CA_STM_CLEAR       1480        /* Condition: stream non crypte.      */
#define CA_STM_CRYPT       1481        /* Condition: pas de CA pour decrypter*/
#define CA_USE_EMB         1482        /* Condition: choix d'1 CA embarque.  */
#define CA_USE_UC          1483        /* Condition: choix d'1 CA emb UC.    */
#define CA_USE_EXT         1484        /* Condition: choix d'1 CA externe.   */
#define CA_USE_DEF         1485        /* Condition: choix d'1 CA par defaut.*/
#define CA_STILL           1486        /* Condition: rester dans le meme etat*/
#define CA_POL_NEXT        1487        /* Temporisation de poling des slots. */
#define CA_FORCE_SEL       1488        /* Force a refaire la selection.      */
#define CA_STM_WAIT        1489        /* Attendre encore le status du stream*/
#define CA_STM_TO          1490        /* Fin d'attente de status.           */
#define CA_DEC_TO          1491        /* Fin d'attente de status d'1 decoder*/
#define CA_ASK_DEC         1492        /* Cnd: Attendre le status d'1 decoder*/
#define CA_SC_EVT          1493        /* Cnd: Carte a puce inseree (driver).*/
#define CA_TIMER           1494        /* Timer specifique d'un slot CA.     */
#define CA_SC_CLOSE        1495        /* Arret d'un slot de carte (standby).*/


/* Automate driver pour Viaccess ............................................*/

#define AUT_VA_DRV         15          /* src/acces/va_drv.c                 */

#define VA_DMX_ALLOC       1504        /* Requete d'allocation d'1 scnl demux*/
#define VA_DMX_SET         1505        /* Requete de configuration d'1 filtre*/
#define VA_DMX_START       1506        /* Requete de demarrage d'1 filtre.   */
#define VA_DMX_STOP        1507        /* Requete d'arret d'1 filtre.        */
#define VA_DMX_FREE        1508        /* Requete de liberation d'1 filtre.  */
#define VA_DMX_SSF         1509        /* Requete de config filtres softwares*/
#define VA_KEY_SET         1510        /* Requete de mise en place de cles.  */
#define VA_KEY_DEL         1511        /* Requete de suppressions de cles.   */
#define VA_SMC_ON          1512        /* Requete de demarrage               */
#define VA_SMC_OFF         1513        /* Requete d'arret                    */
#define VA_SMC_RESET       1514        /* Requete de reset de la carte a puce*/
#define VA_SMC_SEND        1515        /* Requete d'envoi de commande        */
#define VA_SMC_ACT         1516        /* Requete d'activation               */
#define VA_SMC_DEACT       1517        /* Requete de desactivation           */
#define VA_SMC_CLOSE       1518        /* Requete de fermeture               */
#define VA_SEC_INFO        1519        /* Requete de lecture UID et Fuse CWK.*/
#define VA_SEC_MODE        1520        /* Requete de config mode CW.         */
#define VA_SEC_FUSE        1521        /* Requete de fusing CWK.             */
#define VA_SEC_CWK         1522        /* Requete de config CWK.             */
#define VA_SEC_DMA         1523        /* Requete de transfert Secure DMA.   */

#define C_VA_ERROR         1524        /* Cnd: Echec d'une requete.          */
#define C_VA_ERROR2        1525        /* Cnd: Echec d'une requete.          */
#define C_VA_STILL         1526        /* Cnd: Rester dans le meme etat.     */
#define C_VA_SET           1527        /* Cnd: Configurer.                   */
#define C_VA_START         1528        /* Cnd: Demarrer.                     */
#define C_VA_STOP          1529        /* Cnd: Arreter.                      */
#define C_VA_FREE          1530        /* Cnd: Liberer.                      */
#define C_VA_RESET         1531        /* Cnd: Resetter la carte a puce      */
#define C_VA_EMPTY         1532        /* Cnd: Pas/plus de carte.            */
#define C_VA_PTS           1533        /* Cnd: Carte prete pour PTS/T0/T1.   */
#define C_VA_T0            1534        /* Cnd: Carte prete pour T0.          */
#define C_VA_T1            1535        /* Cnd: Carte prete pour T1.          */
#define C_VA_MUTE          1536        /* Cnd: Carte ne repond pas/plus.     */
#define C_VA_SSF           1537        /* Cnd: Reconfig du SSF (filtre SW)   */


/* Automate du VM CAS .......................................................*/
 
#define AUT_VMCAS          16          /* src/acces/vmcas.c                  */
                                       /* Precedent automate deborde de 2!   */
#define VMC_REQ_INIT       1538        /* Requete d'initialisation de VL.    */
#define VMC_REQ_END        1539        /* Requete d'arret de VL.             */
#define VMC_REQ_WRITE      1540        /* Requete d'ecriture.                */
#define VMC_REQ_SETVAL     1541        /* Requete de configuration           */
#define VMC_RESP_INIT      1542        /* Fin d'initialisation de VL.        */
#define VMC_RESP_END       1543        /* Fin d'arret de VL.                 */
#define VMC_TO             1544        /* Fin de temporisation.              */
#define VMC_DATA           1545        /* Nouvelles donnees recues.          */
#define C_VMC_ERR          1546        /* Cnd: Erreur.                       */
#define C_VMC_ERR2         1547        /* Cnd: Erreur.                       */
#define C_VMC_OK           1548        /* Cnd: Succes.                       */
#define C_VMC_READY        1549        /* Cnd: On a fini.                    */
#define C_VMC_NEXT         1550        /* Cnd: Succes, etape suivante.       */
#define C_VMC_END          1551        /* Cnd: Arret a effectuer.            */


/* Automate interface CA ENIGMA .............................................*/

#define AUT_ES_DRV         17          /* src/acces/es_drv.c                 */
#define ES_DMX_ALLOC       1568        /* Requete d'allocation d'1 scnl demux*/
#define ES_DMX_SET         1569        /* Requete de configuration d'1 filtre*/
#define ES_DMX_START       1570        /* Requete de demarrage d'1 filtre.   */
#define ES_DMX_STOP        1571        /* Requete d'arret d'1 filtre.        */
#define ES_DMX_FREE        1572        /* Requete de liberation d'1 filtre.  */
#define ES_DMX_SSF         1573        /* Requete de config filtres softwares*/
#define ES_KEY_SET         1574        /* Requete de mise en place de cles.  */
#define ES_KEY_DEL         1575        /* Requete de suppressions de cles.   */
#define ES_NVM_OPEN        1576        /* Requete d'ouverture de fichier.    */
#define ES_NVM_CLOSE       1577        /* Requete de fermeture de fichier.   */
#define ES_NVM_READ        1578        /* Requete de lecture de fichier.     */
#define ES_NVM_WRITE       1579        /* Requete d'ecriture de fichier.     */
#define ES_UID_GET         1580        /* Requete de lecture de l'UID.       */
#define ES_TO              1581        /* Fin de temporisation.              */
#define C_ES_ERR           1582        /* Condition : erreur rencontree.     */
#define C_ES_ERR2          1583        /* Condition : erreur rencontree.     */
#define C_ES_OK            1584        /* Condition : tout s'est bien passe. */
#define C_ES_STOP          1585        /* Condition : arret.                 */
#define C_ES_SET           1586        /* Condition : redemarrage.           */


/* Automate demux/carte/vnm  pour Aladin ....................................*/

#define AUT_ALA_DMX        18          /* scr/acces/ala_dmx.c                */

#define ALA_DMX_START      1600        /* L'acquisition est lancee.          */
#define ALA_DMX_STOP       1601        /* L'acquisition est arretee.         */
#define ALA_DMX_TO         1602        /* Fin de tempo attente d'acquisition.*/
#define ALA_DMX_STILL      1603        /* Condition: rester dans etat courant*/


#define AUT_ALA_SC         19          /* src/acces/ala_smc.c                */

#define ALA_SMC_OFF        1632        /* Acces au slot n'est plus autorise. */
#define ALA_SMC_ON         1633        /* Acces au slot est autorise.        */
#define ALA_SMC_REQ        1634        /* Une requete io est lancee.         */
#define ALA_SMC_RST        1635        /* Un reset a ete demande.            */
#define ALA_SMC_MOD        1636        /* Aladin demande mode=ACCESS_NONE.   */
#define ALA_SMC_STILL      1637        /* Cnd: rester dans l'etat courant.   */
#define ALA_SMC_WERR       1638        /* Cnd: erreur en emission.           */
#define ALA_SMC_PTS        1639        /* Cnd: envoyer une requete PTS.      */
#define ALA_SMC_RWRT       1640        /* Cnd: driver tente de reemettre.    */


#define AUT_ALA_NVM        20          /* src/acces/ala_nvm.c                */


/* Automate demux/carte pour Conax ..........................................*/

#define AUT_CNX_SMC        21          /* src/acces/cnx_smc.c                */

#define CNX_SMC_OFF        1696        /* Acces au slot n'est plus autorise. */
#define CNX_SMC_ON         1697        /* Acces au slot est autorise.        */
#define CNX_SMC_REQ        1698        /* Une requete io est lancee.         */
#define CNX_SMC_RST        1699        /* Un reset a ete demande.            */
#define CNX_SMC_STILL      1700        /* Cnd: rester dans l'etat courant.   */
#define CNX_SMC_WERR       1701        /* Cnd: erreur en emission.           */
#define CNX_SMC_RERR       1702        /* Cnd: erreur en reception.          */
#define CNX_SMC_DAT        1703        /* Cnd: donnees a lire dans la carte. */


#define AUT_CNX_DMX        22          /* src/acces/cnx_dmx.c                */


/* Automate de gestion de requetes pour Conax ...............................*/

#define AUT_CNX_REQ        23          /* src/acces/cnx_req.c                */

#define CNX_REQ_EXT        1760        /* Extraction de la carte a puce.     */
#define CNX_REQ_INS        1761        /* Insertion d'une carte a puce.      */
#define CNX_REQ_RST        1762        /* Fin de reset de la carte a puce.   */
#define CNX_REQ_END        1763        /* Fin de la requete courante.        */
#define CNX_REQ_INIT_SMC   1764        /* Requete d'initialisation d'une smc.*/
#define CNX_REQ_SEND_CAT   1765        /* Requete d'envoi de la CAT.         */
#define CNX_REQ_SEND_PMT   1766        /* Requete d'envoi de la PMT.         */
#define CNX_REQ_SEND_EMM   1767        /* Requete d'envoi d'un EMM.          */
#define CNX_REQ_SEND_ECM   1768        /* Requete d'envoi d'un ECM.          */
#define CNX_REQ_SEND_STR   1769        /* Requete d'envoi reponse a enquiry. */
#define CNX_REQ_SEND_CHR   1770        /* Requete d'envoi d'un caractere.    */
#define CNX_REQ_OA_SEL     1771        /* Requete d'envoi d'une selection OA.*/
#define CNX_REQ_RELOCK     1772        /* Requete reverrouillage maturity/PPV*/
#define CNX_REQ_CONSULT    1773        /* Requete de consultation de la carte*/
#define CNX_REQ_PINCOM     1774        /* Requete concernant le PIN Code.    */
#define CNX_REQ_RFD        1775        /* Refus de la carte a puce.          */
#define CNX_REQ_STILL      1776        /* Condition: rester dans le meme etat*/
#define CNX_REQ_REINIT     1777        /* Condition: reset de la carte.      */
#define CNX_REQ_ERR        1778        /* Condition: erreur detectee.        */
#define CNX_REQ_RPH        1779        /* Condition: requete vers Return Path*/
#define CNX_REQ_INISESS    1780        /* Condition: initialiser les sessions*/
#define CNX_REQ_READY      1781        /* Condition: carte prete.            */


/* Automate Host pour Conax .................................................*/

#define AUT_CNX_HOST       24          /*                                    */

#define CNX_HOST_EXT       1792        /* Extraction de la carte a puce.     */
#define CNX_HOST_INS       1793        /* Carte inseree, initialisee et prete*/
#define CNX_HOST_END       1794        /* Fin de la requete courante.        */
#define CNX_HOST_EMM       1795        /* Reception d'un EMM.                */
#define CNX_HOST_ECM       1796        /* Reception d'un ECM.                */
#define CNX_HOST_CAT       1797        /* Transmettre la CAT.                */
#define CNX_HOST_PMT       1798        /* Transmettre la PMT.                */
#define CNX_HOST_CHR       1799        /* Transmettre un choix applicatif.   */
#define CNX_HOST_STR       1800        /* Transmettre une saisie applicative.*/
#define CNX_HOST_RELOCK    1801        /* Transmettre demande reverrouillage.*/
#define CNX_HOST_CONSULT   1802        /* Transmettre requete de consultation*/
#define CNX_HOST_PINCOM    1803        /* Transmettre requete liee o PIN Code*/
#define CNX_HOST_ERR       1804        /* Condition: Pb SMC irrecuperable.   */
#define CNX_HOST_WAIT      1805        /* Condition: aller attendre requete. */
#define CNX_HOST_REINIT    1806        /* Condition: reinitialisation smc.   */


/* Automate Mediaguard ......................................................*/

#define AUT_MG_DRV         25          /*                                    */

/* Evenements demux et filtres pour Mediagauard  . . . . . . . . . . . . . . */

#define MG_DMX_CBK         1824        /* Evt: Appeler une callback MG.      */
#define MG_DMX_TABLE       1825        /* Evt: Reception d'une table DVB.    */
#define MG_KEY_SET         1826        /* Evt: Modifier les cles de dechiffrt*/
#define MG_FLT_START       1827        /* Evt: Requete MG de demarrage filtre*/
#define MG_FLT_STOP        1828        /* Evt: Requete MG d'arret d'un filtre*/
#define MG_FLT_TO          1829        /* Evt: Time-out d'attente de section.*/
#define MG_FLT_NONE        1830        /* Cnd: Echec d'allocation de filtre. */
#define MG_FLT_FREE        1831        /* Cnd: Liberer le filtre.            */
#define MG_FLT_ALLOC       1832        /* Cnd: Reallouer le filtre.          */
#define MG_FLT_CFG         1833        /* Cnd: Reconfigurer le filtre.       */

/* Evenements carte a puce pour Mediaguard . . . . . . . . . . . . . . . . . */

#define MG_SMC_ON          1834        /* Acces au slot est autorise.        */
#define MG_SMC_OFF         1835        /* Acces au slot n'est plus autorise. */
#define MG_SMC_CLOSE       1836        /* Fermeture du slot (drv_close).     */
#define MG_SMC_RESET       1837        /* Requete de reset du slot.          */
#define MG_SMC_LOCK        1838        /* Requete de verrouillage du slot.   */
#define MG_SMC_UNLOCK      1839        /* Suppression du verrouillage du slot*/
#define MG_SMC_LOCKTO      1840        /* Time-out verrouillage du slot.     */
#define MG_SMC_PTS         1841        /* Requete PTS pour le slot.          */
#define MG_SMC_SEND        1842        /* Requete d'emission pour le slot.   */
#define MG_SMC_SUBSCR      1843        /* Requete d'enregistrement call-back.*/

#define C_MG_RESET         1844        /* Cnd: Reset avant PTS pour le slot. */
#define C_MG_OK            1845        /* Cnd: Succes d'un PTS sans negocier.*/
#define C_MG_KO            1846        /* Cnd: Echec d'une requete.          */
#define C_MG_EMPTY         1847        /* Cnd: Pas/plus de carte.            */
#define C_MG_PTS           1848        /* Cnd: Carte prete pour PTS/T0/T1.   */
#define C_MG_T0            1849        /* Cnd: Carte prete pour T0.          */
#define C_MG_T1            1850        /* Cnd: Carte prete pour T1.          */
#define C_MG_MUTE          1851        /* Cnd: Carte ne repond pas/plus.     */
#define C_MG_ERROR         1852        /* Cnd: Erreur de communication smc.  */
#define C_MG_IDLE          1853        /* Cnd: Rester dans le meme etat.     */


/* Evenements Non Volatile Memory pour Mediaguard . . . . . . . . . . . . . .*/

#define MG_NVM_WRT         1854        /* Requete MG d'ecriture en NVM.      */

/* Evenements OS pour Mediaguard . . . . . . . . . . . . . . . . . . . . . . */

#define MG_OS_TIM          1855        /* Evt: echeance d'un timer MG.       */
#define MG_OS_INHIBIT      1856        /* Evt: echeance d'un timer MG.       */


/* Automate CA pour Mediaguard ..............................................*/

#define AUT_MG_CA          26          /*                                    */

#define MG_CA_MAT_TO       1856        /* Evt: echeance d'un timer MG.       */
#define MG_CA_PPV_TO       1857        /* Evt: echeance d'un timer MG.       */
#define MG_CA_TST_TO       1858        /* Evt: echeance du timer de test.    */


/* Automate CA DVB-CI .......................................................*/

#define AUT_CI_CA          27          /* "$vmos/acces/dvbci_ca.c"           */

#define IOD_SET            1888        /* Mise en place de l'IOD protocole   */
#define IOD_UNSET          1889        /* Retirer l'IOD de protocole.        */
#define EVT_PRGON          1890        /* Demarrage du dechiffrement         */
#define EVT_PRGUPD         1891        /* La PMT du programme a change       */
#define EVT_PRGOFF         1892        /* Arret du dechiffrement d'un prog.  */
#define C_UPDATE           1893        /* Condition de mise a jour           */
#define C_CAPOS            1894        /* Condition positive de dechiffrage  */
#define C_CANEG            1895        /* Condition negative de dechiffrage  */
#define EVT_PRGADD         1896        /* Demarrage d'un second dechiffrement*/
#define C_HSNEG            1897        /* Host shunning active               */
#define C_HSPOS            1898        /* Host shunning active               */
#define CICA_TO            1899        /* Temporisateur                      */
#define EVT_SDTUPD         1900        /* Chgt SDT                           */
#define CICA_TO2           1901        /* Temporisateur                      */
#define C_CIPLUS           1902        /* Cas Ci + avec Host shunning        */
#define C_SDT_CLR          1903        /* SDT deja presente (cas clear)      */
#define C_SDT_SCR          1904        /* SDT deja presente (cas scramble)   */
#define C_CLEAR            1905        /* Programme en clair                 */
#define C_SCRAMBLED        1906        /* Programme scramble                 */
#define HS_STEP            1907        /* Host shunning                      */
#define HS_TPCHG           1908        /* Changement de TP, SDT a recuperer  */
#define C_RESTART          1909        /* Traitement de restart, cas CI+     */

/* Automate Teletexte .......................................................*/

#define AUT_TTXT           28

#define TTXT_SELECT        1920        /* Selection d'une page pour affichage*/

/* Automate telechargement DSMCC ............................................*/

#define AUT_DSM_FILE       29          /* "$vmos/file/dsmcc.c"               */

/* Automate du service OAD ..................................................*/

#define AUT_SRV_OAD        31          /* "$vmos/telecom/srv_oad.c"          */

#define OAD_START          2016        /* Debut de recherche OAD.            */
#define OAD_STOP           2017        /* Arret forcee de recherche OAD.     */
#define OAD_TO             2018        /* Timeout de telechargement OAD.     */
#define C_OAD_SBOTH        2019        /* Cnd: charger PAT + (NIT ou BAT).   */
#define C_OAD_SPAT         2020        /* Cnd: charger PAT.                  */
#define C_OAD_SNIT         2021        /* Cnd: charger NIT.                  */
#define C_OAD_SBAT         2022        /* Cnd: charger BAT.                  */
#define C_OAD_SPMT         2023        /* Cnd: charger PMT.                  */
#define C_OAD_SUNT         2024        /* Cnd: charger UNT.                  */
#define C_OAD_SDSI         2025        /* Cnd: charger DSI.                  */
#define C_OAD_SDII         2026        /* Cnd: charger DII.                  */
#define C_OAD_SSC0         2027        /* Cnd: charger Section 0.            */
#define C_OAD_SB0          2028        /* Cnd: charger Bloc 0 du volume.     */
#define C_OAD_WBLK         2029        /* Cnd: charger autres blocs du vol.  */
#define C_OAD_WWRT         2030        /* Cnd: attendre fin d'ecriture.      */
#define C_OAD_FOUND_I      2031        /* Cnd: on a trouve, IDLE.            */
#define C_OAD_FOUND_S      2032        /* Cnd: on a trouve, STOP.            */
#define C_OAD_FAILED_S     2033        /* Cnd: echec/erreur, STOP.           */
#define C_OAD_FAILED_I     2034        /* Cnd: echec/erreur, IDLE.           */
#define C_OAD_DONE         2035        /* Cnd: telechargement du vol termine.*/
#define C_OAD_CONTINUE     2036        /* Cnd: rester dans l'etat courant.   */
#define C_OAD_GIVEN        2037        /* Cnd: donnees transmises par l'appli*/

/* Automate driver pour SecureMedia : AUT_SM_DRV ............................*/

#define AUT_SM_DRV         32          /* "$vmos/acces/sm_drv.c"             */
#define SM_NVM_WRT         2048        /* Requete d'ecriture en NVM.         */
#define SM_FLT_START       2049        /* Evt: Requete de demarrage filtre.  */
#define SM_FLT_STOP        2050        /* Evt: Requete d'arret d'un filtre.  */
#define SM_FLT_NONE        2051        /* Cnd: Echec d'allocation de filtre. */
#define SM_FLT_FREE        2052        /* Cnd: Liberer le filtre.            */
#define SM_FLT_ALLOC       2053        /* Cnd: Reallouer le filtre.          */
#define SM_FLT_CFG         2054        /* Cnd: Reconfigurer le filtre.       */
#define SM_KEY_SET         2055        /* Evt: Ecrire cles de dechiffrement. */
#define SM_KEY_DEL         2056        /* Evt: Supprimer cles de dechiffremnt*/
#define SM_GET_UID         2057        /* Evt: Requete lecture Unique Id.    */
#define SM_GET_RND         2058        /* Evt: Requete nombre aleatoire.     */
#define SM_GET_MAC         2059        /* Evt: Requete lecture adresse MAC.  */
#define SM_HTTP_GET        2060        /* Evt: Requete HTTP Get.             */
#define SM_HTTP_TO         2061        /* Evt: Fin de temporisation HTTP.    */
#define SM_HTTP_OK         2062        /* Cnd: Succes de requete HTTP.       */
#define SM_HTTP_KO         2063        /* Cnd: Echec  de requete HTTP.       */
#define SM_HTTP_KO2        2064        /* Cnd: Echec  de requete HTTP.       */


/* Nombre max d'automates ...................................................*/
/*ATTENTION a mettre la meme valeur dans le define NAUTMAX des fichiers *.sys*/

#define AUTLAST            35          /* Dernier numero d'automate          */


/*****************************************************************************
 * Numeros des automates du VMIO                                             *
 * -----------------------------                                             *
 *                                                                           *
 * Ces numeros d'automates sont compris entre 128 et 255                     *
 *                                                                           *
 * Pour chaque numero d'automate, on trouve a la suite les codes de ses      *
 * evenements "prives". Le premier de ces codes est toujours egal a          *
 * 1024 + 32 * numero de l'automate. De ce fait, on dispose de 32 codes      *
 * pour chacun des automates                                                 *
 *****************************************************************************/

#define FEVT(aut) (1024+32*(aut))      /* Premier code d'evenenement dispo.  */
#define LEVT(aut) (1024+32*(aut)+31)   /* Dernier code d'evenenement dispo.  */

#define AUTS_FIRST         128         /* Numero premier automate simplifie  */

/* Automate de resolution des noms de drivers ...............................*/

#define AUT_RESOLVE        128         /* vmio/drvsys/drv_rslv.c             */

/* Automate interface clavier/telecommande ..................................*/

#define AUT_KBDITF         129         /* vmio/drvcar/drv_kbditf.c           */

/* Automate DAC .............................................................*/

#define AUT_DAC            130         /* vmio/drvcar/drv_dac.c              */

/* Automate ADC .............................................................*/

#define AUT_ADC            131         /* vmio/drvcar/drv_adc.c              */

/* Automate ASY .............................................................*/

#define AUT_ASY              135       /* vmio/drvsys/drv_asy.c              */

#define REQ_IO              5344       /* Requete de relance req_lib.c       */
#define IT_SIG              5345       /* Changement d'etat signal de jnctin */

#define TO_SIG0             5346       /* Tempo file d'ecriture              */
#define TO_SIG1             5347       /* Tempo file de lecture              */
#define TO_SIG2             5348       /* Tempo file autre                   */
#define TO_MSEC0            5349       /* Tempo file d'ecriture              */
#define TO_MSEC1            5350       /* Tempo file de lecture              */
#define TO_MSEC2            5351       /* Tempo file autre                   */

#if REQ_IO != FEVT(AUT_ASY)
  #error "AUT_ASY first event has wrong number !"
#endif

#if TO_MSEC2 > LEVT(AUT_ASY)
  #error "AUT_ASY defines too many events !"
#endif

/* Automate SRF .............................................................*/

#define AUT_SRF            136         /* vmio/drvcar/drv_srf.c              */

/* Automate BLT .............................................................*/

#define AUT_BLT            137         /* vmio/drvcar/drv_blt.c              */

/* Automate SPI .............................................................*/

#define AUT_SPI            138         /* vmio/drvsys/drv_spi.c              */

/* Automate GPIO ............................................................*/

#define AUT_GPIO           139         /* vmio/drvsys/drv_gpio.c             */

/* Automate LED .............................................................*/

#define AUT_LED            140         /* vmio/drvcar/drv_led.c              */

/* Automate protocoles infra-rouge (RCU) ....................................*/

#define AUT_RCU            141         /* vmio/drvsys/drv_rcu.c              */

#define C_S               5536         /* Cond capture des symboles          */
#define C_T               5537         /* Cond telecommande a leader/tail    */
#define C_R               5538         /* Cond telecommande a repetition mess*/
#define C_6               5539         /* Cond telecommande RC6 mode 0       */
#define C_5               5540         /* Cond telecommande RC5              */
#define C_X               5541         /* Cond protocole XMP                 */
#define C_M               5542         /* Cond protocole RCMM                */
#define C_EVT             5543         /* Cond evt a remonter au VMOS        */
#define C_NOEVT           5544         /* Cond pas d'evt a remonter au VMOS  */
#define C_RCU             5545         /* Cond message RCU                   */
#define C_KBD             5546         /* Cond message Clavier               */
#define C_MSE             5547         /* Cond message Souris                */
#define C_PFIN            5548         /* Cond prochain symbole est STOP     */

#if C_S != FEVT(AUT_RCU)
  #error "AUT_RCU first event has wrong number !"
#endif

#if C_PFIN > LEVT(AUT_RCU)
  #error "AUT_RCU defines too many events !"
#endif





/* ATTENTION : NB MAX D'AUTOMATES VMIO DEFINI PAR MAXAUT_S ! ! !             */
/* PJB 22/09/2015 : Depuis aujourd'hui ce dernier automate est defini dans   */
/* vmiodat_xyz.c . Dans le cas vmiodat_iotc.c, MAXAUT_S = 16, et le dernier  */
/* automate autorise est le __144__.                                         */


#endif
