/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/xdrv_asy.h"            */
/*  Constants and definition of ASY driver.                                  */
/*                                                                           */
/*  Author : JYA                        Last modification : 06/12/2017       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef XDRV_ASY_H                     /* If this file is not already        */
#define XDRV_ASY_H                     /* included, include it.              */


/*
    1    Defines
    ____________
*/

/* Definitions des champs de bit pour la description des devices ............*/

/* Definition des baudrate predefinis */

#define BR_0                 0         /* Baudrate nul = Arret de l'ASY      */
#define BR_50                1         /* 50 Bauds                           */
#define BR_75                2         /* 75 Bauds                           */
#define BR_110               3         /* 110 Bauds                          */
#define BR_134               4         /* 134 Bauds                          */
#define BR_150               5         /* 150 Bauds                          */
#define BR_200               6         /* 200 Bauds                          */
#define BR_300               7         /* 300 Bauds                          */
#define BR_600               8         /* 600 Bauds                          */
#define BR_1200              9         /* 1200 Bauds                         */
#define BR_1800             10         /* 1800 Bauds                         */
#define BR_2400             11         /* 2400 Bauds                         */
#define BR_4800             12         /* 4800 Bauds                         */
#define BR_9600             13         /* 9600 Bauds                         */
#define BR_19200            14         /* 19200 Bauds                        */
#define BR_38400            15         /* 38400 Bauds                        */
#define BR_57600            16         /* 57600 Bauds                        */
#define BR_115200           17         /* 115200 Bauds                       */
#define BR_ALL  ((1<<(BR_115200+1))-1) /* Tous les modes supportes           */

/* Definiton des stop bits */

#define ST_05                1         /* 0.5 stop bits                      */
#define ST_1                 2         /* 1 stop bits                        */
#define ST_15                4         /* 1.5 stop bits                      */
#define ST_2                 8         /* 2 stop bits                        */
#define ST_ALL             0xF         /* Tous les modes supportes           */

/* Definition de la parite */

#define PAR_NONE             1         /* Pas de parite                      */
#define PAR_ODD              2         /* Parite ODD                         */
#define PAR_EVEN             4         /* Parite EVEN                        */
#define PAR_ALL            0x7         /* Tous les modes supportes           */

/* Definitions supplementaires */

#define OTH_CTS           0x01         /* Hardware flow control support      */
#define OTH_FIFO          0x04         /* FIFO available                     */
#define OTH_CTSDMA        0x10         /* RTS/CTS handling done by DMA       */
#define OTH_DMA           0x40         /* DMA available                      */

#define ASY_NBREG           10
#define NBBLK                4
#define SZBLK              128


/*
    2    Structures and typedefs
    ____________________________
*/

/* Structure de description d'une liaison asynchrone  .......................*/

typedef struct                         /* Description device Asy             */
  BEGIN                                /* ---------------------------------- */
    void         (*info)         ()  ; /* Nom du device ASY                  */
    void         (*setline)      ()  ; /* Ecrire parametres de ligne UART    */
    void         (*setflow)      ()  ; /* Communiquer parametres flow control*/
    void         (*setsig)       ()  ; /* Changer etats RTS DTR TXBREAK      */
    void         (*getsig)       ()  ; /* Lire etats CTS DSR RI DCD RXBREAK  */
    void         (*ittx)         ()  ; /* Autoriser/Interdire IT TX          */
    IWORD        (*putbyte)      ()  ; /* Ecrire un cara dans FIFO TX        */
    IWORD        (*getbyte)      ()  ; /* Lire un cara depuis FIFO RX        */
    void         (*setto)        ()  ; /* Armer temporisateur CHAR/FRAME     */
                                       /*                                    */
    IWORD        (*snddma)       ()  ; /* Demarrer emission avec DMA ASY     */
    IWORD        (*rcvdma)       ()  ; /* Demarrer reception avec DMA ASY    */
    IWORD        (*rcvdmastop)   ()  ; /* Arreter reception avec DMA ASY     */

  END            Asy_desc            ; /* ---------------------------------- */


typedef struct                         /* Definition  device Asy             */
  BEGIN                                /* ---------------------------------- */
    UINT         ldevnum             ; /* Index de device utilise par la     */
                                       /* couche basse                       */
    UINT         supp_speed          ; /* Vitesses supportees par le device  */
    UCHAR        supp_stop           ; /* Nombre de stop bits supportes      */
    UCHAR        supp_size[5]        ; /* Mode de parite supportes           */
    UCHAR        supp_other          ; /* Autre modes supportes par le device*/
  END            Asy_drvdef          ; /* ---------------------------------- */


typedef struct                         /* Contexte device ASY                */
  BEGIN                                /* ---------------------------------- */
    Hd_ctx       hctx                ; /* En-tete de contexte                */
    Req_ctx      rctx                ; /* Les files de Jobs                  */
    Key_lnk      key                 ; /* Une et une seul clef par device    */
    Blkio_ctx    blkio               ; /* Contexte pour xxx_write/xxx_read   */
    UCHAR        blk[NBBLK][SZBLK]   ; /* Buffers  pour xxx_write/xxx_resd   */
    Circ_buf     cbuf                ; /* Buffer circulaire pour pipe        */
    Next_lnk     nlnk                ; /* References entite a droite         */
                                       /*                                    */
    void         (*setline)      ()  ; /* Ecrire parametres de ligne UART    */
    void         (*setflow)      ()  ; /* Communiquer parametres flow control*/
    void         (*setsig)       ()  ; /* Changer etats RTS DTR TXBREAK      */
    void         (*getsig)       ()  ; /* Lire etats CTS DSR RI DCD RXBREAK  */
    void         (*ittx)         ()  ; /* Autoriser/Interdire IT TX          */
    IWORD        (*putbyte)      ()  ; /* Ecrire un cara dans FIFO TX        */
    IWORD        (*getbyte)      ()  ; /* Lire un cara depuis FIFO RX        */
    void         (*setto)        ()  ; /* Armer temporisateur CHAR/FRAME     */
    IWORD        (*snddma)       ()  ; /* Demande d'emission DMA ASY         */
    IWORD        (*rcvdma)       ()  ; /* Demande de reception DMA ASY       */
    IWORD        (*rcvdmastop)   ()  ; /* Demande arret reception DMA ASY    */
                                       /*                                    */
    Asy_drvdef * def                 ; /* Definitions du device              */
    UINT         ldevnum             ; /* Low level device index             */
                                       /*                                    */
    IWORD        (*cb_send)      ()  ; /* Call back fin de asy_send          */
    IWORD        (*cb_rcv)       ()  ; /* Call back reception un buffer      */
    IWORD        (*cb_io)        ()  ; /* Call back fin execution "asy_io"   */
    IWORD        (*cb_ind)       ()  ; /* Call back pour IND_REPORT          */
    INT          inihigh             ; /* Ref contexte empilement du dessus  */
                                       /*                                    */
    UINT         reg[ASY_NBREG]      ; /* Valeurs des registres              */
                                       /*                                    */
    USHORT       char1               ; /* Cara 1 de remontee                 */
    USHORT       char2               ; /* Cara 2 de remontee                 */
    USHORT       char3               ; /* Cara 2 de remontee                 */
    USHORT       maxframe            ; /* Taille maximale d'une trame        */
    USHORT       minframe            ; /* Taille minimale d'une trame        */
    USHORT       tmode               ; /* 0:NONE  1:CHARACTER  2:FRAME       */
    USHORT       tempo               ; /* Temporisateur, en millisecondes    */
    USHORT       flowctl             ; /* 0:NONE  1:RTS/CTS  2:XON/XOFF      */
    USHORT       bufsize             ; /* BUFSIZE                            */
    USHORT       dma                 ; /* 0:octet par octet 1:mode DMA       */
                                       /*                                    */
    UCHAR        buf[64]             ; /* Si aucun buffer de reception       */
    USHORT       ibuf                ; /* Indice prochain octet a recevoir   */
                                       /*                                    */
    UCHAR        *snd                ; /* Adresse du buffer d'emission       */
    USHORT       sndsize             ; /* Nombre d'octets a emettre          */
    USHORT       isnd                ; /* Indice prochain octet a emettre    */
                                       /*                                    */
    UCHAR        *rcv                ; /* Adresse du buffer de reception     */
    USHORT       rcvsize             ; /* Taille du buffer de reception      */
    USHORT       ircv                ; /* Indice prochain octet a recevoir   */
                                       /*                                    */
    UCHAR        stoptx              ; /* 1 si flot en sortie est bloque     */
    UCHAR        stoprx              ; /* 1 si flot en entree est bloque     */
    UCHAR        asyto               ; /* 1 si TO UART en train de courir    */
    UCHAR        rts                 ; /* 1 si notre RTS est VRAI            */
    UCHAR        sndblk              ; /* 1 si ecriture bloquante (asy_write)*/
    UCHAR        rcvblk              ; /* 1 si lecture  bloquante (asy_read )*/
 
  END            Asy_ctx             ; /* ---------------------------------- */


/*
    3    Public variable
    _______________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/

/* Procedures appelees par les controleurs d'interruption ...................*/

  void  itasyrx             (IWORD                                           );
  void  itasytx             (IWORD                                           );
  void  itasyto             (IWORD                                           );
  void  itasysig            (IWORD                                           );
  void  itasydmarx          (IWORD,INT,INT                                   );
  void  itasydmatx          (IWORD                                           );


/* Procedures d'interface du driver systeme .................................*/

extern UCHAR asy_numdrv              ; /* Numero du driver ASY               */
extern UCHAR asy_sysdrv              ; /* Numero du driver ASY               */

  IWORD asy_get_rctx        (INT, Req_ctx**                                  );
  IWORD asy_set_line        (Req_ctx*, INT, INT, INT, INT, INT               );
  IWORD asy_set_signals     (Req_ctx*, INT, INT, INT, INT                    );
  IWORD asy_set_eom         (Req_ctx*, USHORT *, INT, INT, INT, INT, INT     );
  IWORD asy_set_flowctl     (Req_ctx*, INT, INT, INT                         );
  IWORD asy_get_all         (Req_ctx*, INT                                   );
  IWORD asy_send            (Req_ctx*, UCHAR *, INT, INT, INT                );
  IWORD asy_receive         (Req_ctx*, INT, INT, UCHAR*, INT, INT            );
  IWORD asy_io              (Req_ctx*, Job *, INT                            );
  IWORD asy_write           (INT,UCHAR*,INT                                  );
  IWORD asy_read            (INT,UCHAR*,INT,INT*                             );


/* Procedures d'interface pour affichage console ............................*/

  IWORD asy_write           (INT, UCHAR *, INT                               );
  IWORD asy_read            (INT, UCHAR *, INT, INT *                        );


#endif                                 /* End of XDRV_ASY_H.                 */
